@@ -966,8 +966,9 @@ class Askdata(SignUp):
         else:
             final_df = df
             while(len(df.index) == 1000):
-                df = self.query(workspace=workspace_slug, dataset=dataset_slug, fields=all_fields, limit=(limit+1000), offset=limit)
+                df = self.query(workspace=workspace_slug, dataset=dataset_slug, fields=all_fields, limit=1000, offset=limit)
                 final_df = final_df.append(df)
+                limit+=1000
             return final_df
 
     def __retrieve_og_columns(self, conditions:list, df:pd.DataFrame):
